@@ -3,15 +3,10 @@
 
 /* camel-stub.h: class for a stub to talk to the backend */
 
-
 #ifndef CAMEL_STUB_H
 #define CAMEL_STUB_H 1
 
-
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus }*/
+G_BEGIN_DECLS
 
 #include <camel/camel-object.h>
 #include <camel/camel-operation.h>
@@ -43,7 +38,6 @@ typedef struct {
 
 } CamelStubClass;
 
-
 /* Standard Camel function */
 CamelType  camel_stub_get_type    (void);
 
@@ -56,11 +50,7 @@ gboolean   camel_stub_send        (CamelStub *stub, CamelException *ex,
 gboolean   camel_stub_send_oneway (CamelStub *stub,
 				   CamelStubCommand command, ...);
 
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* CAMEL_STUB_H */
 
-
